runner

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 3, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Reader io.Reader      = StreamReader{}
	Writer io.WriteCloser = StreamWriter{}
)

Functions

func CallAPI

func CallAPI(apiName string, request []byte) ([]byte, error)

CallAPI stub

func Checkpoint

func Checkpoint()

Checkpoint stub

func GetTime

func GetTime() time.Time

GetTime stub

func Run

func Run(steps ...func() error) int32

Run stub

Types

type APICall

type APICall struct {
	// contains filtered or unexported fields
}

APICall represents a stub fluent builder for external host API calls.

func Call

func Call(apiName string) *APICall

Call stub

func (*APICall) Send

func (c *APICall) Send() ([]byte, error)

Send stub

func (*APICall) WithPayload

func (c *APICall) WithPayload(payload []byte) *APICall

WithPayload stub

type StreamReader

type StreamReader struct{}

StreamReader stub

func (StreamReader) Read

func (r StreamReader) Read(p []byte) (n int, err error)

type StreamWriter

type StreamWriter struct{}

StreamWriter stub

func (StreamWriter) Close

func (w StreamWriter) Close() error

func (StreamWriter) Write

func (w StreamWriter) Write(p []byte) (n int, err error)

type Workflow

type Workflow struct {
	// contains filtered or unexported fields
}

Workflow represents a stub fluent builder for workflow steps.

func NewWorkflow

func NewWorkflow() *Workflow

NewWorkflow stub

func (*Workflow) Run

func (w *Workflow) Run() int32

Run stub

func (*Workflow) Step

func (w *Workflow) Step(step func() error) *Workflow

Step stub

Jump to